( cd opt/kde/lib ; rm -rf libtext2path.so )
( cd opt/kde/lib ; ln -sf libtext2path.so.0.0.0 libtext2path.so )
( cd opt/kde/lib ; rm -rf libkimageviewer.so )
( cd opt/kde/lib ; ln -sf libkimageviewer.so.0.0.0 libkimageviewer.so )
( cd opt/kde/lib ; rm -rf libtext2path.so.0 )
( cd opt/kde/lib ; ln -sf libtext2path.so.0.0.0 libtext2path.so.0 )
( cd opt/kde/lib ; rm -rf libkpovmodeler.so )
( cd opt/kde/lib ; ln -sf libkpovmodeler.so.0.0.0 libkpovmodeler.so )
( cd opt/kde/lib ; rm -rf libkscan.so )
( cd opt/kde/lib ; ln -sf libkscan.so.1.0.0 libkscan.so )
( cd opt/kde/lib ; rm -rf libkmultipage.so.0 )
( cd opt/kde/lib ; ln -sf libkmultipage.so.0.0.0 libkmultipage.so.0 )
( cd opt/kde/lib ; rm -rf libkghostviewlib.so.0 )
( cd opt/kde/lib ; ln -sf libkghostviewlib.so.0.0.0 libkghostviewlib.so.0 )
( cd opt/kde/lib ; rm -rf libkimageviewer.so.0 )
( cd opt/kde/lib ; ln -sf libkimageviewer.so.0.0.0 libkimageviewer.so.0 )
( cd opt/kde/lib ; rm -rf libkghostviewlib.so )
( cd opt/kde/lib ; ln -sf libkghostviewlib.so.0.0.0 libkghostviewlib.so )
( cd opt/kde/lib ; rm -rf libkpovmodeler.so.0 )
( cd opt/kde/lib ; ln -sf libkpovmodeler.so.0.0.0 libkpovmodeler.so.0 )
( cd opt/kde/lib ; rm -rf libksvg.so.0 )
( cd opt/kde/lib ; ln -sf libksvg.so.0.0.1 libksvg.so.0 )
( cd opt/kde/lib ; rm -rf libkscan.so.1 )
( cd opt/kde/lib ; ln -sf libkscan.so.1.0.0 libkscan.so.1 )
( cd opt/kde/lib ; rm -rf libkmultipage.so )
( cd opt/kde/lib ; ln -sf libkmultipage.so.0.0.0 libkmultipage.so )
( cd opt/kde/lib ; rm -rf libksvg.so )
( cd opt/kde/lib ; ln -sf libksvg.so.0.0.1 libksvg.so )
( cd opt/kde/share/doc/HTML/en/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdvi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpdf ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kooka ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kamera ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kgamma ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kgamma ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kruler ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kuickshow ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kolourpaint ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kiconedit ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kghostview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kpovmodeler ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/en/common common )
