<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kpdf_part" version="13">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="file_print" group="file_print"/>
    <Action name="file_print_preview" group="file_print"/>
  </Menu>
  <Menu name="view"><text>&amp;View</text>
    <Action name="fit_to_width"/>
    <Separator/>
    <Action name="zoom_in"/>
    <Action name="zoom_out"/>
  </Menu>
  <Menu name="go"><text>&amp;Go</text>
    <Action name="back"/>
    <Action name="forward"/>
    <Separator/>
    <Action name="previous_page"/>
    <Action name="next_page"/>
    <Separator/>
    <Action name="goToPage"/>
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="show_scrollbars" group="show_merge"/>
    <Action name="show_page_list" group="show_merge"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="zoom_in"/>
  <Action name="zoomTo" />
  <Action name="zoom_out"/>
  <Separator/>
  <Action name="previous_page"/>
  <Action name="next_page"/>
  <Action name="goToStart"/>
  <Action name="goToEnd"/>
</ToolBar>
</kpartgui>
