<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kpdf_shell" version="5">
<MenuBar>
  <Menu name="file">
    <DefineGroup name="file_save" append="save_merge"/>
    <DefineGroup name="file_print" append="print_merge"/>
  </Menu>
  <Menu name="view">
    <Action name="fullscreen"/>
  </Menu>
  <Menu name="settings">
    <DefineGroup name="show_merge" append="show_merge"/>
  </Menu>
  <Merge/>
</MenuBar>
</kpartgui>
